==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d3/d6b/network__udp_8cpp.js <==
var network__udp_8cpp =
[
    [ "NetworkUDPQueryServerInfo", "d0/dd2/structNetworkUDPQueryServerInfo.html", "d0/dd2/structNetworkUDPQueryServerInfo" ],
    [ "MasterNetworkUDPSocketHandler", "d7/d8c/classMasterNetworkUDPSocketHandler.html", "d7/d8c/classMasterNetworkUDPSocketHandler" ],
    [ "ServerNetworkUDPSocketHandler", "d8/d3c/classServerNetworkUDPSocketHandler.html", "d8/d3c/classServerNetworkUDPSocketHandler" ],
    [ "ClientNetworkUDPSocketHandler", "da/d6b/classClientNetworkUDPSocketHandler.html", "da/d6b/classClientNetworkUDPSocketHandler" ],
    [ "NetworkBackgroundUDPLoop", "d3/d6b/network__udp_8cpp.html#ab92b04eb19c2b9a3939a6e3554ceb5b7", null ],
    [ "NetworkUDPAdvertise", "d3/d6b/network__udp_8cpp.html#aa7bdd6fe9bb421540e5a01b8a2d0686b", null ],
    [ "NetworkUDPAdvertiseThread", "d3/d6b/network__udp_8cpp.html#a3929070d9c6ea72544a632bda659b817", null ],
    [ "NetworkUDPBroadCast", "d3/d6b/network__udp_8cpp.html#ae43fe92afd7106de0d4073ea041a6b09", null ],
    [ "NetworkUDPClose", "d3/d6b/network__udp_8cpp.html#a389f8f4240c0d267993fe9b166ff8813", null ],
    [ "NetworkUDPInitialize", "d3/d6b/network__udp_8cpp.html#a5474ac64d11be2108b9d68c52e907f89", null ],
    [ "NetworkUDPQueryMasterServer", "d3/d6b/network__udp_8cpp.html#aa3dd98ab083a6e7922dfd50bc997fba2", null ],
    [ "NetworkUDPQueryServer", "d3/d6b/network__udp_8cpp.html#a977d39c42beaf4fc628e912c605ca13a", null ],
    [ "NetworkUDPQueryServer", "d3/d6b/network__udp_8cpp.html#added7294f811b558a85a1a5676ce2260", null ],
    [ "NetworkUDPQueryServerThread", "d3/d6b/network__udp_8cpp.html#a5e127191aea1de87636989a4a59d1064", null ],
    [ "NetworkUDPRemoveAdvertise", "d3/d6b/network__udp_8cpp.html#ae133b2e05e12e884059d8cc8150fd90c", null ],
    [ "NetworkUDPRemoveAdvertiseThread", "d3/d6b/network__udp_8cpp.html#a58e15ee7549da61e8ce746c1645053f4", null ],
    [ "NetworkUDPSearchGame", "d3/d6b/network__udp_8cpp.html#a5f7706dc543fe027f67da85353cbe135", null ],
    [ "_network_udp_mutex", "d3/d6b/network__udp_8cpp.html#adc9eedb78d84b06bd10481416f2b674b", null ],
    [ "_session_key", "d3/d6b/network__udp_8cpp.html#a0f4027e9c24b313a2d88405e4dca9f2d", null ],
    [ "_udp_client_socket", "d3/d6b/network__udp_8cpp.html#a1be6da59933b9643c0faa72d54e2942e", null ],
    [ "_udp_master_socket", "d3/d6b/network__udp_8cpp.html#a6f69fbb83d2db878c58dc8bbc76277ec", null ],
    [ "_udp_server_socket", "d3/d6b/network__udp_8cpp.html#a11db8e92f9a0e6b94ec9eae514a49f0d", null ],
    [ "ADVERTISE_NORMAL_INTERVAL", "d3/d6b/network__udp_8cpp.html#a729ddb03681cd7a45878bc57a701594d", null ],
    [ "ADVERTISE_RETRY_INTERVAL", "d3/d6b/network__udp_8cpp.html#a21f734dc9d3afd386d0b9311908afb03", null ],
    [ "ADVERTISE_RETRY_TIMES", "d3/d6b/network__udp_8cpp.html#a8d59e032f1449c34ea3ecacc3c0c2f08", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d3/d6b/network__udp_8cpp.js <==
var network__udp_8cpp =
[
    [ "MasterNetworkUDPSocketHandler", "d7/d8c/classMasterNetworkUDPSocketHandler.html", "d7/d8c/classMasterNetworkUDPSocketHandler" ],
    [ "ServerNetworkUDPSocketHandler", "d8/d3c/classServerNetworkUDPSocketHandler.html", "d8/d3c/classServerNetworkUDPSocketHandler" ],
    [ "ClientNetworkUDPSocketHandler", "da/d6b/classClientNetworkUDPSocketHandler.html", "da/d6b/classClientNetworkUDPSocketHandler" ],
    [ "DoNetworkUDPQueryServer", "d3/d6b/network__udp_8cpp.html#a516e06cc9ff685b31058e9840e6e1faa", null ],
    [ "NetworkBackgroundUDPLoop", "d3/d6b/network__udp_8cpp.html#ab92b04eb19c2b9a3939a6e3554ceb5b7", null ],
    [ "NetworkUDPAdvertise", "d3/d6b/network__udp_8cpp.html#aa7bdd6fe9bb421540e5a01b8a2d0686b", null ],
    [ "NetworkUDPAdvertiseThread", "d3/d6b/network__udp_8cpp.html#a4e53a410387c00fa5db76ff772ec3894", null ],
    [ "NetworkUDPBroadCast", "d3/d6b/network__udp_8cpp.html#ae43fe92afd7106de0d4073ea041a6b09", null ],
    [ "NetworkUDPClose", "d3/d6b/network__udp_8cpp.html#a389f8f4240c0d267993fe9b166ff8813", null ],
    [ "NetworkUDPInitialize", "d3/d6b/network__udp_8cpp.html#a5474ac64d11be2108b9d68c52e907f89", null ],
    [ "NetworkUDPQueryMasterServer", "d3/d6b/network__udp_8cpp.html#aa3dd98ab083a6e7922dfd50bc997fba2", null ],
    [ "NetworkUDPQueryServer", "d3/d6b/network__udp_8cpp.html#added7294f811b558a85a1a5676ce2260", null ],
    [ "NetworkUDPRemoveAdvertise", "d3/d6b/network__udp_8cpp.html#ae133b2e05e12e884059d8cc8150fd90c", null ],
    [ "NetworkUDPRemoveAdvertiseThread", "d3/d6b/network__udp_8cpp.html#a6cc7ab61612819f5066fdd6560220d0d", null ],
    [ "NetworkUDPSearchGame", "d3/d6b/network__udp_8cpp.html#a5f7706dc543fe027f67da85353cbe135", null ],
    [ "_network_udp_mutex", "d3/d6b/network__udp_8cpp.html#a1cfd6e8e9b45bfeff97ddd6b3ab1ac2f", null ],
    [ "_session_key", "d3/d6b/network__udp_8cpp.html#a0f4027e9c24b313a2d88405e4dca9f2d", null ],
    [ "_udp_client_socket", "d3/d6b/network__udp_8cpp.html#a1be6da59933b9643c0faa72d54e2942e", null ],
    [ "_udp_master_socket", "d3/d6b/network__udp_8cpp.html#a6f69fbb83d2db878c58dc8bbc76277ec", null ],
    [ "_udp_server_socket", "d3/d6b/network__udp_8cpp.html#a11db8e92f9a0e6b94ec9eae514a49f0d", null ],
    [ "ADVERTISE_NORMAL_INTERVAL", "d3/d6b/network__udp_8cpp.html#a729ddb03681cd7a45878bc57a701594d", null ],
    [ "ADVERTISE_RETRY_INTERVAL", "d3/d6b/network__udp_8cpp.html#a21f734dc9d3afd386d0b9311908afb03", null ],
    [ "ADVERTISE_RETRY_TIMES", "d3/d6b/network__udp_8cpp.html#a8d59e032f1449c34ea3ecacc3c0c2f08", null ]
];
